@@ -1,7 +1,6 @@
 
-if (!covr::in_covr()) {
-  skip_on_cran()
-}
+skip_on_cran()
+skip_if_offline()
 
 if (Sys.info()["sysname"] == "Linux") {
   httr::set_config(httr::config(ssl_verifypeer = FALSE))
@@ -92,4 +91,4 @@ test_that("it should company_cash_dividends_download ", {
     trading_name = "AMBEVSA"
   )
   expect_true(f)
-})
\ No newline at end of file
+})
